@@ -16,6 +16,8 @@ class state_sales_tax(Variable):
         TAX_UNIT_SIZE_CAP = 6
         tax_unit_size = tax_unit("tax_unit_size", period)
         capped_unit_size = max_(min_(tax_unit_size, TAX_UNIT_SIZE_CAP), 1)
-        income_bracket = tax_unit("state_sales_tax_income_bracket", period)
+        income_bracket = max_(
+            tax_unit("state_sales_tax_income_bracket", period), 1
+        )
         state_code = tax_unit.household("state_code", period)
         return p.tax[state_code][capped_unit_size][income_bracket]
